%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Create a vertical grid using the following equation:
%% z(k) = h0 -h1k-h2h3log(cosh(k-h4)/h3);
%% k = 1:jpk for w levels and k = 1+1/2:jpk+1/2 for t levels;
%% e3(k) = h1-h2tanh((k-h4)/h3);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all;

%% what I want;

jpk = 41;        % Number of layers + 1;
e3i = -4;        % Thickness of first layer;
e3e = -300;      % Thickness of last layer;
zi  = 0;         % Depth at first layer;
ze  = -3600;     % Maximum depth;
h3  = 8;         % Parameter which controls the increasing of the layers thickness;
                 % if h3 increases the thikness of the layers increases faster at the begining;

opath = '/net/wave3/ganeshgopal/WAVE5_DATA/GOM_OI_24DEG/FORCINGS/';
vgridname = 'vgrid_gom';


%% Determine h0, h1, h2;

ind = 0;
h4int = [1:0.005:jpk];
for h4 = h4int
  ind = ind+1;
  [h2,h1,h0] = funvg1(h4,h3,jpk,e3i,e3e,zi);
  rap3 = (jpk-h4)/h3;
  zfind(ind) = h0 - h1*jpk - h2*h3*log(cosh(rap3));
end


%% Determine h4 such that zfind(h4) = ze;

ih4 = find(zfind >= ze-1 & zfind <= ze+1);
h4 = min(h4int(ih4));


%% final results;

[h2,h1,h0] = funvg1(h4,h3,jpk,e3i,e3e,zi);

for ik = 1:jpk
  z(ik) = h0-h1*ik-h2*h3*log(cosh((ik-h4)/h3));
end

dz = z(2:jpk)-z(1:jpk-1);
ra = dz(1:jpk-2)./dz(2:jpk-1);

figure; plot(z,'+');
figure; plot(1./ra,'+');
figure; bar(-dz);

depth = z';
depth(end) = ze;

eval(['save ' opath vgridname ' depth -ascii']); 
 
